# rm(list=ls(all=TRUE))


# Estimation of Laeken indicators using synthetic EU-SILC data
library(laeken)

# Load synthetic databse of Austria EU-SILC 2006
data("eusilc")
head(eusilc, 3)
# Only a few of the large number of variables in the original survey are included in 
# the example dataset. 

# METADATA EU-SILC 2006
# https://www.gesis.org/en/missy/metadata/EU-SILC/2006/Cross-sectional/original

#equivalized household size according to the modified OECD scale needs to be computed.
#This can be done with the function eqSS(), which requires the household ID and the age of the
#individuals as arguments.  
#In the example data, household ID and age are stored in the variables db030 and age
eusilc$eqSS <- eqSS("db030", "age", data=eusilc)
head(eusilc[,c("db030", "age", "eqSS")], 10)


# Then the equivalized disposable income can be computed with the function
# eqInc().  It requires the  following  information  to  be  supplied:  
# the  household  ID,  
# the  household  income  components to be added and subtracted, 
# the personal income  components to be added and subtracted, respectively, 
# the equivalized household size

# The net income is considered in this example, therefore no personal income component
# needs to be subtracted

# hy040n: income from rental of a property or land (net). 
# hy050n: family/children related allowances (net). 
# hy070n: housing allowances (net).
# hy080n: regular inter-household cash transfer received (net).
# hy090n: interest, dividends, profit from capital investments in unincorporated business (net).
# hy110n: income received by people aged under 16 (net).

hplus <- c("hy040n", "hy050n", "hy070n", "hy080n", "hy090n", "hy110n")


# hy130n: regular inter-household cash transfer paid (net).
# hy145n: repayments/receipts for tax adjustment (net).

hminus <- c("hy130n", "hy145n")

# py010n numeric; employee cash or near cash income (net).
# py050n numeric; cash benefits or losses from self-employment (net). 
# py090n numeric; unemployment benefits (net).
# py100n numeric; old-age benefits (net).
# py110n numeric; survivor's benefits (net).
# py120n numeric; sickness benefits (net).
# py130n numeric; disability benefits (net).
# py140n numeric; education-related allowances (net).

pplus <- c("py010n", "py050n", "py090n", "py100n",
           "py110n", "py120n", "py130n", "py140n")


eusilc$eqIncome <- eqInc("db030", hplus, hminus,
                          pplus, character(), "eqSS", data=eusilc)

head(eusilc[,c("db030", "eqSS", "eqIncome")], 10)


# Currently, the following indicators are available in the R package laeken
# At-risk-of-poverty rate:   arpr()
# Quintile share ratio:  qsr()
# Relative median at-risk-of-poverty gap:  rmpg()
# Dispersion around the at-risk-of-poverty threshold:   arpr()
# Gini coefficient :   gini()

# At-risk-at-poverty rate
arpr("eqIncome", weights = "rb050", breakdown = "db040", data = eusilc)

# It is also possible to use these functions for the estimation of the indicator
# dispersion  around the at-risk-of-poverty threshold, which is defined as the 
# proportion of persons with an equivalized disposable income below 40%, 50% and 70% 
# of the national weighted median equivalized disposable income.  
# The proportion of the median equivalized income to be used can thereby be adjusted via
# the argument 'p'

arpr("eqIncome", weights = "rb050", p = 0.4, data = eusilc)
arpr("eqIncome", weights = "rb050", p = 0.5, data = eusilc)
arpr("eqIncome", weights = "rb050", p = 0.7, data = eusilc)

# However, any kind of breakdown can be supplied, e.g., the breakdowns defined by Eurostat.  
# With the following lines of code, a breakdown variable with all possible combinations of age
# categories and gender is defined and added to the data set, before it is used to compute estimates
# for the corresponding domains.
ageCat <- cut(eusilc$age, c(-1, 16, 25, 50, 65, Inf), right=FALSE)
# right logical, indicating if the intervals should be closed on the right (and open on the left) 
# or vice versa.
eusilc$breakdown <- paste(ageCat, eusilc$rb090, sep=":")
arpr("eqIncome", weights = "rb050", breakdown = "breakdown", data = eusilc)


# The income quintile share ratio (QSR) is defined as the ratio of the 
# sum of the equivalized disposable income received by the 20% of the population with the 
# highest equivalized disposable income to that received by the 20% of the population with 
# the lowest equivalized disposable income

# With package laeken , the quintile share ratio can be estimated using the function qsr()
qsr("eqIncome", weights = "rb050", data = eusilc)


# The Gini coefficient is defined The Gini coefficient is based on the comparison of 
# cumulative proportions of the population against cumulative proportions of income they receive
gini("eqIncome", weights = "rb050", data = eusilc)


# VARIANCE ESTIMATION
# computing confidence intervals: national level
a <- arpr(eusilc$eqIncome, weights = eusilc$rb050, design =eusicl$db040) 
bootVar(inc=eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040, 
        indicator=a, R=500, bootType="naive", ciType="perc", seed = 8)
#design: an optional vector or factor giving different strata for stratified sampling designs
# a  stratified  sampling  design  can  be considered by specifying the
# design argument, in which case observations are resampled separately within the strata. 
#------------------------------------------------------------------------------------

setwd("~/WEB PISA/Lezioni JM 2018/R Lab 08 Nov 2018")

# sample EU-SILC ITALY

# https://www.gesis.org/en/missy/metadata/EU-SILC/2009/Cross-sectional/original

# Household Register (D): every selected household, 
#                         including those where the address could not be contacted or 
#                         those households that could not be interviewed
# Household Data (H): completed household interview
# Personal Data (P): contain a record for every eligible person for whom the information could 
#                    be completed from interview and/or registers
# Personal Register (R): contain a record for every person currently living in the household 
#                        or temporarily absent


IT<-read.csv("ITALY_SILC.csv")
# calculate equivalized household size
#library(laeken)
IT$eqSS <- eqSS("hb030", "rx020", data=IT)

#Procedure for the equivalized disposable income

# Equivalised disposable income= [HY020+sum(PY080G)] / eqSS
# HY020: TOTAL DISPOSABLE HOUSEHOLD INCOME
# py080g: Regular pensions from individual private plans
#

# assign 0 if a missing value is in py080g
IT$py080g[is.na(IT$py080g)] <- 0
#calcuate the py080g for each househol
fy080<-tapply(IT$py080g, IT$hb030, sum)
# save the number of members in each household
freq<-data.frame(table(IT$hb030))
#add the py080g-household level at each household member 
IT$fy080_household<-rep(fy080,freq$Freq)

# calucalate the disposable income (without onsider the Equivalence Scale)
IT$income_eu=IT$hy020+ IT$fy080_household

# Equivalised disposable income
IT$income_eu_eq=IT$income_eu/IT$eqSS

# Weighted mean of Eq Disposable income
# rb050: PERSONAL CROSS-SECTIONAL WEIGHT
weighted.mean(IT$income_eu_eq,IT$rb050)

weightedMedian(IT$income_eu_eq,IT$rb050)*0.6


#HCR
arpr("income_eu_eq", weights = "rb050", data = IT)

# breakdown HCR
# HCR for regions
# DB040:REGION (NUTS 1: for Italy -> Groups of regions)
table(IT$db040)
# ITC 	Northwest	
# ITF 	South 	
# ITG 	Islands 	
# ITH 	Northeast
# ITI 	Centre
arpr("income_eu_eq", weights = "rb050", breakdown = "db040",data = IT)

# However, any kind of breakdown can be supplied, e.g., the breakdowns defined by Eurostat.  
# With the following lines of code, a breakdown variable with all possible combinations of age
# categories and gender is defined and added to the data set, before it is used to compute estimates
# for the corresponding domains.
# rx020: age
# rb090: gender -> 1:MALE; 2:FEMALE
# summary(IT_09$rx020)
ageCat <- cut(IT$rx020, c(0, 16, 25, 50, 65, Inf), right=FALSE)
# right logical, indicating if the intervals should be closed on the right (and open on the left) 
# or vice versa.
IT$breakdown <- paste(ageCat, IT$rb090, sep=":")
arpr("income_eu_eq", weights = "rb050", breakdown = "breakdown", data = IT)

# VARIANCE ESTIMATION
# computing confidence intervals: national level
HCR <- arpr("income_eu_eq", weights = "rb050", data = IT)
bootVar(inc=IT$income_eu_eq, weights = IT$rb050, design =IT$db040, 
        indicator=HCR, R=500, bootType="naive", ciType="perc", seed = 8)
#design: an optional vector or factor giving different strata for stratified sampling designs
# a  stratified  sampling  design  can  be considered by specifying the
# design argument, in which case observations are resampled separately within the strata. 


# The income quintile share ratio (QSR) is defined as the ratio of the 
# sum of the equivalized disposable income received by the 20% of the population with the 
# highest equivalized disposable income to that received by the 20% of the population with 
# the lowest equivalized disposable income

# With package laeken , the quintile share ratio can be estimated using the function qsr()
qsr("income_eu_eq", weights = "rb050", data = IT)


# The Gini coefficient is defined as the relationship of cumulative shares of the 
# population arranged according to the level of equivalized disposable income, to the cumulative 
# share of the equivalized total disposable income received by them
gini("income_eu_eq", weights = "rb050", data = IT)


# MAPPING HCR for italy in the Macro Regions
library(maptools)
require(mapproj)
library(RColorBrewer)

italy<- readShapePoly("~/WEB PISA/Lezioni JM 2018/R Lab 08 Nov 2018/ITA_adm/ITA_adm1.shp")
plot(italy)
# this file is for map with NUTS-2 borders
View(italy)
italy$REMARKS_1
table(italy$ID_1, italy$REMARKS_1)
# the variable REMARKS_1 store the name of MACRO-REGIONS (NUTS 1)
# but with different names
# ITC: Northwest (=)
# ITD: Northeast (ITH)
# ITE: Centre (ITI)
# ITF: South (=)
# ITG: Islands (=)

#built a dataframe with HCR and Regions (NUTS-1HC)
HCR0<-arpr("income_eu_eq", weights = "rb050", breakdown = "db040",data = IT)

HCR_DF<-data.frame(REMARKS_1=c("ITC", "ITF", "ITG", "ITD", "ITE"), HCR=HCR0$valueByStratum$value)
IT_map<- merge(italy, HCR_DF, by="REMARKS_1")

#set colors
nclr <- 3
plotclr <- brewer.pal(nclr,"OrRd")

#cut-off (arbitrary)
IT_map$cutHCR <- cut(IT_map$HCR, c(0,7.00,18.26,Inf), 
                     right = F, include.lowest=T) 


spplot(IT_map, "cutHCR", col.regions=plotclr, 
       colorkey = list(space="bottom",height = 1, 
                       labels = list(at = seq(0.5, 4 -0.5), 
                                                                labels = c(0,7.00,18.26,37.88))))



#------------------------------------------------------------------

#                 MAPPING USING ggplot()

#------------------------------------------------------------------
rm(list=ls())

library(maptools)
library(ggplot2)

# get italy provinces (NUTS-2) map
italy_map <- map_data("italy")

# name of map provided by the maps package. 
# These include maps::county(), maps::france(), maps::italy(), 
# maps::nz(), maps::state(), 
# maps::usa(), maps::world(), maps::world2().
head(italy_map)
# look at the  provinces (NUTS-3) names
print(unique(italy_map$region))
region=unique(italy_map$region)

# we'll simulate some data 
# HCR is a index between 0 and 1 
#simulate data from a uniform distribution 0-1 
set.seed(8) #set a seed (reproducible exam)
choro_dat <- data.frame(region=unique(italy_map$region),
                        value=runif(length(region), 0,1))
head(choro_dat)
gg <- ggplot()

gg <- ggplot()

# lay down the base layer
gg <- gg + geom_map(data=italy_map, map=italy_map,
                    aes(long, lat, map_id=region),
                    col="grey", size=0.5, fill="NA")

# col is the color of the borders of the provinces
# size is the dimensions of the borders
# if you plot gg now you obtain just a map of italy with no colors and data

# fill in the regions with the data
gg <- gg + geom_map(data=choro_dat, map=italy_map,
                    aes(fill=value, map_id=region),
                    color="grey", size=0.5) +
  scale_fill_gradient(low="yellow", high="red", 
                      limits = c(0,1), breaks = c(0, 0.25, 0.5, 0.75, 1))

gg
